@@ -16,8 +16,8 @@ import math
 
 #}}}
 
-VERSION = "1.5"
-PROToVERSION = "1.5"
+VERSION = "1.6"
+PROToVERSION = "1.6"
 
 #{{{ Mnemonics List
 
@@ -181,6 +181,7 @@ VALUeMNEMONICS = {
   "is":"inset",
   "it":"italic",
   "le":"left",
+  "lg":"linear-gradient",
   "li":"linear",
   "lo":"lowercase",
   "mi":"middle",
@@ -191,6 +192,7 @@ VALUeMNEMONICS = {
   "pb":"padding-box",
   "po":"pointer",
   "re":"relative",
+  "rg":"radial-gradient",
   "ri":"right",
   "rx":"repeat-x",
   "ry":"repeat-y",
@@ -527,9 +529,12 @@ class a_defines(object):
     # to avoid substring substitutions inside @cod-defines
     me.db = []
   def add_def( me, name, body ):
-    pat1 = r"(?<!%s)" % DEFINeNAMeCHAR
+    # because of - in arythmeticts, this is not possible
+    #pat1 = r"(?<!%s)" % DEFINeNAMeCHAR
+    pat1 = r"\b"
     pat2 = re.escape( name ) 
-    pat3 = r"(?!%s)" % DEFINeNAMeCHAR
+    #pat3 = r"(?!%s)" % DEFINeNAMeCHAR
+    pat3 = r"\b"
     pat4 = r"(?:\s*\((.*?)\))?" # optional parentheses
 
     patin = re.compile( pat2 + pat4 ) 
@@ -875,7 +880,7 @@ DECLARATIOnRE = re.compile( r"""
 """ % STRINgSUBRE, re.S | re.X ) 
 
 # TODO str supp
-VALUeRE = re.compile( r"(\S+\s*\(.*?\)|\S+)"  )
+VALUeRE = re.compile( r"([\w!%-]+)(\s*\(.*?\))?"  )
 UNItRE = re.compile( r"\b\d+([a-z])\b" )
   
 def apply_mnemonics( cut ):
@@ -1170,7 +1175,7 @@ if __name__ == "__main__":
     argparse.ArgumentParser.add_argument = argparse.ArgumentParser.add_option
 
   parser = argparse.ArgumentParser(
-    description= "CSS-On-Diet - preprocessor for CSS files",
+    description= "CSS-On-Diet - preprocessor for CSS files - ver. %s" % VERSION,
     epilog="www.cofoh.com/css-on-diet"
   )
 
@@ -1192,12 +1197,19 @@ if __name__ == "__main__":
     help="Minify CSS result code. Implies --no-comments and --no-header"
   )
   parser.add_argument(
-    '-I', '--include-dirs', metavar='dir[,dir...]', 
-    help="List of additional directories to look for included files. Separtor is the comma sign."
+    '-I', '--include-dirs', metavar='dir[,dir...]',
+    action='append', # repeating arguments
+    help="List of additional directories to look for included files. " +\
+         "Multiple dirs can be separated by commas or by multiple " +\
+         "-I(--include-dirs) arguments."
+  )
+  parser.add_argument(
+    '-v', '--version',  action="store_true",
+    help="Print software and specification versions"
   )
   # FINISH
   if not optmode:
-    parser.add_argument('cod_files', metavar='file.cod', nargs="+",
+    parser.add_argument('cod_files', metavar='file.cod', nargs="*",
                         help='CSS-On-Diet file to preprocess.' +
                         ' Multiple files are joined.' +
                         ' If "-" given read from STDIN instead of file.')
@@ -1206,6 +1218,16 @@ if __name__ == "__main__":
     (args, leftargs) = parser.parse_args()
     args.cod_files = leftargs
 
+  if args.version:
+    print("Version %s (for specification %s)" % (VERSION, PROToVERSION))
+    sys.exit(0)
+
+  # has to be after args.version
+  if len( args.cod_files ) < 1:
+    sys.stderr.write("Error: Give at least one file to preprocess\n")
+    sys.exit(1)
+    
+
   stdinasfile = 0
   for f in args.cod_files:
     if f == "-":
@@ -1220,7 +1242,10 @@ if __name__ == "__main__":
     args.no_header = True
 
   if args.include_dirs:
-    args.include_dirs = args.include_dirs.split(",")
+    result = []
+    for i in args.include_dirs:
+      result += i.split(",")
+    args.include_dirs = result
   else:
     args.include_dirs = [] # more useful than None
 
